// ArduCAM demo (C)2012 Lee
// web: http://www.ArduCAM.com
// This program is a demo of how to use most of the functions
// of the library with a supported camera modules.
//
// This demo was made for Omnivision OV2640 sensor,
// Capture the image from the LCD and send to serial port 1.
// This program requires the ArduCAM shield Rev.B and UNO R3 hardware,
// and ArduCAM library V2.1.0 and Arduino1.0 or later.
//

#include <UTFT.h>
#include <Wire.h>
#include <ArduCAM.h>
#include <avr/pgmspace.h>
#include <SoftwareSerial.h>

//ArduCAM(byte model,int RS, int WR, int RD, int CS)
ArduCAM myCAM(OV2640,A2,A1,A0,A3,10);
SoftwareSerial mySerial(9, 8); // RX, TX

void setup()
{
  Wire.begin(); 
  mySerial.begin(115200);
  mySerial.println("hello"); 
 
  //Flush the FIFO 
  myCAM.flush_fifo();		 
  
  myCAM.write_reg(ARDUCHIP_TIM, MODE_MASK);
  myCAM.OV2640_set_format(JPEG);
  myCAM.InitCAM();
  myCAM.OV2640_set_JPEG_size(OV2640_320x240);


}

void loop()
{
  uint8_t temp,temp_last;
  uint8_t start_capture = 0;
  temp = mySerial.read();
  switch(temp)
  {
    case 0:
      myCAM.OV2640_set_JPEG_size(OV2640_160x120);
      break;
    case 1:
      myCAM.OV2640_set_JPEG_size(OV2640_176x144);
      break;
    case 2:
      myCAM.OV2640_set_JPEG_size(OV2640_320x240);
      break;
    case 3:
      myCAM.OV2640_set_JPEG_size(OV2640_352x288);
      break;
    case 4:
      myCAM.OV2640_set_JPEG_size(OV2640_640x480);
      break;
    case 5:
      myCAM.OV2640_set_JPEG_size(OV2640_800x600);
      break;
    case 6:
      myCAM.OV2640_set_JPEG_size(OV2640_1024x768);
      break;
    case 7:
      myCAM.OV2640_set_JPEG_size(OV2640_1280x1024);
      break;
    case 8:
      myCAM.OV2640_set_JPEG_size(OV2640_1600x1200);
      break;
      
    case 0x10:
      start_capture = 1;
      //mySerial.println("start"); 
      break;
    default:
      break;
  }
 
  if(start_capture)
  {
    //Clear the capture done flag 
    myCAM.clear_fifo_flag();	 
    //Start capture
    myCAM.start_capture();	 
  }
  if(myCAM.read_reg(ARDUCHIP_TRIG) & CAP_DONE_MASK)
  {
    //Enable FIFO
    myCAM.enable_fifo();
    temp = myCAM.read_fifo();
    while( (temp != 0xD9) | (temp_last != 0xFF) )
    {
        temp_last = temp;
	temp = myCAM.read_fifo();
	mySerial.write(temp);
    }
    //Disable FIFO when all the image data is saved to the file
    myCAM.disable_fifo(); 
    //Clear the capture done flag 
    myCAM.clear_fifo_flag();
    start_capture = 0;
  }
      
        
}

